use serde::{Deserialize, Serialize};

#[derive(Serialize, Deserialize, Debug)]
#[serde(untagged)]
pub enum WolvesResultUserResult {
    B(bool),
    S(String),
}

#[derive(Deserialize, Serialize, Debug)]
struct WolvesResultUser {
    success: i64,
    result: WolvesResultUserResult,
}

async fn get_user(wolves_url_base: &str, api_key: &str ,email: &str) -> Option<i64> {
    let url = format!("{}/get_id_from_email", wolves_url_base);

    match reqwest::Client::new()
        .post(&url)
        .form(&[("email", email)])
        .header("X-AM-Identity", api_key)
        .send()
        .await
    {
        Ok(x) => {
            if let Ok(y) = x.json::<WolvesResultUser>().await {
                // this is the only time we will get a positive response, the None at the end catches everything else
                if let WolvesResultUserResult::S(z) = y.result {
                    if let Ok(id) = z.parse::<i64>() {
                        return Some(id);
                    }
                }
            }
        }
        Err(e) => {
            dbg!(e);
        }
    }

    None
}